# RZLogger

Make easy to log all your projects

## Set up for local development

- if you don't have pip installed, install it first
- run `pip install rizallogger`

## Import and use the logger

Now you can use the logger by accessing the class `Log`.

`from rzlogger import Log`
`Log.warning('your error message')`

